﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.Json.Serialization;
using System.Threading.Tasks;

namespace Tr.Sdk
{
    public interface ITrClient
    {
        /// <summary>
        /// 执行操作呼叫中心请求
        /// </summary>
        /// <typeparam name="TRequest"></typeparam>
        /// <typeparam name="TResponse"></typeparam>
        /// <param name="request"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task<TResponse?> ExecuteAsync<TRequest, TResponse>(
            TRequest request,
            CancellationToken cancellationToken) where TRequest : ITrRequest;

        Task<string> GetTokenAsync(TokenRequest request, CancellationToken cancellationToken);
    }

    public class TokenRequest : ITrRequest
    {
        public TokenRequest()
        {
            Url = "login/token";
            Method = HttpMethod.Get;
        }

        public string Url { get; init; }

        public HttpMethod Method { get; init; }

        public string Username { get; set; }

        public string Password { get; set; }
    }

    public interface ITrRequest
    {
        [JsonIgnore]
        string Url { get; }

        [JsonIgnore]
        HttpMethod Method { get; }
    }
}
